// TypeScript-Definitionen für die Backend-API-Responses

// Steckdosenmodell (entspricht dem Backend socket)
export interface BackendPrinter {
  id: string;
  name: string;
  description: string;
  status: number;  // 0=available, 1=busy
  ipAddress?: string;
  connectionStatus?: string;
  lastSeen?: string;
  uptimeInfo?: {
    offline_since?: string;
    offline_duration?: number;
    offline_duration_formatted?: string;
  };
  latestJob?: BackendJob | null;
  waitingJobs?: BackendJob[];
}

// Druckauftrag (entspricht dem Backend job)
export interface BackendJob {
  id: string;
  socketId: string;  // Backend nennt es socketId statt printerId
  userId: string;
  startAt: string;
  durationInMinutes: number;
  comments: string | null;
  aborted: boolean;
  abortReason: string | null;
  waitingApproval?: boolean;
  remainingMinutes?: number;
}

// Für die Kartierung zwischen Frontend und Backend
export const mapBackendPrinterToFrontend = (printer: BackendPrinter) => {
  return {
    id: printer.id,
    name: printer.name,
    description: printer.description,
    status: printer.status,
    // Weitere Felder für Frontend-Anpassungen
    connectionStatus: printer.connectionStatus || 'unknown',
    uptimeInfo: printer.uptimeInfo,
    // Transformiere das aktuelle Job-Format
    printJobs: printer.latestJob ? [mapBackendJobToFrontend(printer.latestJob)] : [],
    // Weitere wartende Jobs
    waitingJobs: printer.waitingJobs?.map(mapBackendJobToFrontend) || [],
  };
};

export const mapFrontendPrinterToBackend = (printer: any) => {
  return {
    id: printer.id,
    name: printer.name,
    description: printer.description,
    status: printer.status,
    // Frontend hat keine IP-Adresse, diese wird vom Backend verwaltet
  };
};

export const mapBackendJobToFrontend = (job: BackendJob) => {
  return {
    id: job.id,
    printerId: job.socketId, // Anpassung des Feldnamens
    userId: job.userId,
    startAt: new Date(job.startAt),
    durationInMinutes: job.durationInMinutes,
    comments: job.comments || '',
    aborted: job.aborted,
    abortReason: job.abortReason || '',
    waitingApproval: job.waitingApproval || false,
    remainingMinutes: job.remainingMinutes || 0,
  };
};

export const mapFrontendJobToBackend = (job: any) => {
  return {
    printerId: job.printerId, // Im Backend als socketId
    userId: job.userId,
    durationInMinutes: job.durationInMinutes,
    comments: job.comments || '',
    // Die restlichen Felder werden vom Backend verwaltet
  };
};